### Tuto — Switch to Python 3.10
Generate a MATER project, if not already existing.  
```bash
uvx init-mater-project my-3-10-project
```

In `pyproject.toml`, change required Python version to 3.10.  
```toml
[project]
# ...
requires-python = ">=3.10"
```

Update uv Python version to 3.10.  
```bash
# if needed
# uv python install 3.10

uv python pin 3.10
```

Sync dependencies and Python version.  
```bash
uv sync
```

> [!tip] Check it worked correctly in `.python-version` file.

Follow your README project instructions as usual.